@@ -28,15 +28,28 @@
 namespace Bakery
 {
 
-void GtkDialogs::ui_warning(const Glib::ustring& text)
+void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ustring& secondary_text)
 {
-  Gtk::MessageDialog dialog(text, Gtk::MESSAGE_WARNING);
-  dialog.run(); //deletes it too.
+  Gtk::MessageDialog dialog("<b>" + text + "</b>", true /* use markup */, Gtk::MESSAGE_WARNING);
+  dialog.set_secondary_text(secondary_text);
+
+  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+  if(pWindow)
+    dialog.set_transient_for(*pWindow);
+
+  dialog.set_title(""); //The HIG says that alert dialogs should not have titles. The default comes from the message type.
+
+  dialog.run();
 }
 
-Glib::ustring GtkDialogs::ui_file_select_open()
+Glib::ustring GtkDialogs::ui_file_select_open(App& app)
 {
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
+
+  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+  if(pWindow)
+    fileChooser_Open.set_transient_for(*pWindow);
+
   fileChooser_Open.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Open.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
 
@@ -52,9 +65,14 @@ Glib::ustring GtkDialogs::ui_file_select_open()
     return "";
 }
 
-Glib::ustring GtkDialogs::ui_file_select_save(const Glib::ustring& old_filepath)
+Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old_filepath)
 {
   Gtk::FileChooserDialog fileChooser_Save(gettext("Save Document"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+
+  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+  if(pWindow)
+    fileChooser_Save.set_transient_for(*pWindow);
+
   fileChooser_Save.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   fileChooser_Save.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
 
@@ -74,11 +92,16 @@ Glib::ustring GtkDialogs::ui_file_select_save(const Glib::ustring& old_filepath)
     return "";
 }
 
-App_WithDoc::enumSaveChanges GtkDialogs::ui_offer_to_save_changes(const std::string& filepath)
+App_WithDoc::enumSaveChanges GtkDialogs::ui_offer_to_save_changes(App& app, const std::string& filepath)
 {
   App_WithDoc::enumSaveChanges result = App_WithDoc::SAVECHANGES_Cancel;
 
   Bakery::Dialog_OfferSave* pDialogQuestion = new Bakery::Dialog_OfferSave(filepath);
+
+  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+  if(pWindow)
+    pDialogQuestion->set_transient_for(*pWindow);
+
   Bakery::Dialog_OfferSave::enumButtons buttonClicked = (Bakery::Dialog_OfferSave::enumButtons)pDialogQuestion->run();
   delete pDialogQuestion;
   pDialogQuestion = 0;
@@ -93,9 +116,14 @@ App_WithDoc::enumSaveChanges GtkDialogs::ui_offer_to_save_changes(const std::str
   return result;
 }
 
-bool GtkDialogs::ui_ask_overwrite(const std::string& filepath)
+bool GtkDialogs::ui_ask_overwrite(App& app, const std::string& filepath)
 {
    Bakery::Dialog_OverwriteFile* pDialogQuestion = new Bakery::Dialog_OverwriteFile(filepath);
+
+  Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
+  if(pWindow)
+    pDialogQuestion->set_transient_for(*pWindow);
+
    Bakery::Dialog_OverwriteFile::enumButtons buttonClicked = (Bakery::Dialog_OverwriteFile::enumButtons)pDialogQuestion->run();
    delete pDialogQuestion;
    pDialogQuestion = 0;
