@@ -16,7 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "ViewBase.h"
+#include "bakery/View/ViewBase.h"
 
 namespace Bakery
 {
@@ -49,4 +49,4 @@ void ViewBase::clipboard_clear()
 {
 }
 
-} //namespace
\ No newline at end of file
+} //namespace
